==> org-lsst-ccs-command-2.1.2-sources.jar: org/lsst/ccs/command/MethodBasedCommandDictionary.java <==
package org.lsst.ccs.command;

import java.util.ArrayList;

/**
 * An implementation of Dictionary which implements commands by linking to
 * annotated methods on an underlying command.
 *
 * @author tonyj
 */
class MethodBasedCommandDictionary extends ArrayList<DictionaryCommand> implements Dictionary {

    private static final long serialVersionUID = 4401762766383746012L;
    private final DefaultDictionaryCompleter completer = new DefaultDictionaryCompleter(this);

    @Override
    public boolean containsCommand(BasicCommand tc) throws CommandArgumentMatchException {
        return findCommand(tc) != null;
    }

    @Override
    public DictionaryCommand findCommand(BasicCommand tc) throws CommandArgumentMatchException {
        String command = tc.getCommand();
        int argumentCount = tc.getArgumentCount();
        ArrayList<DictionaryCommand> matches = new ArrayList<>();

        ArrayList<CommandArgumentMatchException> exceptions = new ArrayList<>();

        for (DictionaryCommand def : this) {
            try {
                if (DictionaryUtils.commandMatch(def, tc)) {
                    matches.add(def);
                }
            } catch (CommandArgumentMatchException ex) {
                exceptions.add(ex);
            }
        }
        if (matches.isEmpty()) {
            CommandArgumentMatchException.throwExceptionIfNeeded(exceptions);
            return null;
        } else if (matches.size() == 1) {
            return matches.get(0);
        } else {
            throw new AmbiguousCommandException("Error finding command " + command + " with " + argumentCount + " arguments: " + matches.size() + " matches found in MethodBasedCommandDictionary");
        }
    }

    @Override
    public DictionaryCompleter getDictionaryCompleter() {
        return completer;
    }

}

==> org-lsst-ccs-command-2.1.10-sources.jar: org/lsst/ccs/command/MethodBasedCommandDictionary.java <==
package org.lsst.ccs.command;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import org.lsst.ccs.command.annotations.Command;

/**
 * An implementation of Dictionary which implements commands by linking to
 * annotated methods on an underlying command.
 *
 * @author tonyj
 */
class MethodBasedCommandDictionary extends ArrayList<DictionaryCommand> implements Dictionary {

    private static final long serialVersionUID = 4401762766383746012L;
    private final DefaultDictionaryCompleter completer = new DefaultDictionaryCompleter(this);
    
    private int level = Command.NOT_DEFINED;

    private Map<Command.CommandType, Boolean> visibilityByType = new HashMap<>();
    
    @Override
    public boolean containsCommand(BasicCommand tc) throws CommandArgumentMatchException {
        return findCommand(tc) != null;
    }

    @Override
    public DictionaryCommand findCommand(BasicCommand tc) throws CommandArgumentMatchException {
        String command = tc.getCommand();
        int argumentCount = tc.getArgumentCount();
        ArrayList<DictionaryCommand> matches = new ArrayList<>();

        ArrayList<CommandArgumentMatchException> exceptions = new ArrayList<>();

        for (DictionaryCommand def : this) {
            try {
                if (DictionaryUtils.commandMatch(def, tc)) {
                    matches.add(def);
                }
            } catch (CommandArgumentMatchException ex) {
                exceptions.add(ex);
            }
        }
        if (matches.isEmpty()) {
            CommandArgumentMatchException.throwExceptionIfNeeded(exceptions);
            return null;
        } else if (matches.size() == 1) {
            return matches.get(0);
        } else {
            throw new AmbiguousCommandException("Error finding command " + command + " with " + argumentCount + " arguments: " + matches.size() + " matches found in MethodBasedCommandDictionary");
        }
    }

    @Override
    public DictionaryCompleter getDictionaryCompleter() {
        return completer;
    }

    @Override
    public void setLevel(int level) {
        this.level = level;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public void setVisibilityForTypes(Command.CommandType... types) {
        if (visibilityByType == null) {
            // For backward compatibility on the buses
            visibilityByType = new HashMap<>();
        }
        for(Command.CommandType type : Command.CommandType.values()) {
            visibilityByType.put(type, false);
        }
        for(Command.CommandType type : types) {
            visibilityByType.put(type, true);
        }
    }

    @Override
    public boolean getVisibilityForType(Command.CommandType type) {
        if (visibilityByType == null) {
            // For backward compatibility on the buses
            visibilityByType = new HashMap<>();
        }
        return visibilityByType.get(type) == null ? true : visibilityByType.get(type);
    }
}
